Return a summary of the estimation routine for gross output functions from gnrprod.
# S3 method for gnr
summary(object, ...)a list of class 'summary.gnr' containing 14 elements:
output_name: the name of the output variable.
fixed_names: a vector of the names of fixed input variables.
flex_name: the name of the flexible input variable.
data: data returned by gnrprod.
data_name: the name of data.
fs_conv: a boolean indicating if convergence was achieved in the first stage.
ss_conv: the convergence code of optim used in the second stage.
productivity: matrix of the estimated total productivity.
fs_iter: the number of iterations in the first stage.
fs_SSR: sum of squared residuals in the first stage.
ss_iter: the number of iterations in the second stage.
ss_val: the value of the objective function in the second stage.
ss_iter: the number of iterations in the second stage.
ss_mes: the convergence message in the second stage.
an object of class 'gnr'.
currently not used.